Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(16)

Unified Diff: third_party/WebKit/Source/platform/weborigin/KURLTest.cpp

Issue 2333753002: Remove equalIgnoringCase in Source/platform/weborigin/ (Closed)
Patch Set: Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/weborigin/KURLTest.cpp
diff --git a/third_party/WebKit/Source/platform/weborigin/KURLTest.cpp b/third_party/WebKit/Source/platform/weborigin/KURLTest.cpp
index b3c0a2a4b50b0bba49197911801c4624ffd6189e..6c2cfdca99eac3c294a7b09fd9c86bf1692358b5 100644
--- a/third_party/WebKit/Source/platform/weborigin/KURLTest.cpp
+++ b/third_party/WebKit/Source/platform/weborigin/KURLTest.cpp
@@ -155,13 +155,13 @@ TEST(KURLTest, DISABLED_UTF8)
// When the result is ASCII, we should get an ASCII String. Some
// code depends on being able to compare the result of the .string()
// getter with another String, and the isASCIIness of the two
- // strings must match for these functions (like equalIgnoringCase).
- EXPECT_TRUE(equalIgnoringCase(asciiKURL, String(asciiURL)));
+ // strings must match for these functions (like equalIgnoringASCIICase).
+ EXPECT_TRUE(equalIgnoringASCIICase(asciiKURL, String(asciiURL)));
- // Reproduce code path in FrameLoader.cpp -- equalIgnoringCase implicitly
+ // Reproduce code path in FrameLoader.cpp -- equalIgnoringASCIICase implicitly
// expects gkurl.protocol() to have been created as ascii.
KURL mailto(ParsedURLString, "mailto:foo@foo.com");
- EXPECT_TRUE(equalIgnoringCase(mailto.protocol(), "mailto"));
+ EXPECT_TRUE(equalIgnoringASCIICase(mailto.protocol(), "mailto"));
const char utf8URL[] = "http://foo/bar#\xe4\xbd\xa0\xe5\xa5\xbd";
KURL utf8KURL(ParsedURLString, utf8URL);

Powered by Google App Engine
This is Rietveld 408576698